@@ -1,9 +1,10 @@
 """Provides the basic types used for checks."""
 
 import abc
+from collections.abc import Mapping
 import configparser
 from datetime import datetime
-from typing import Any, Mapping, Optional, Type, TypeVar
+from typing import Any, TypeVar
 
 from autosuspend.util import logger_by_class_instance
 
@@ -43,7 +44,7 @@ class Check(abc.ABC):
     @classmethod
     @abc.abstractmethod
     def create(
-        cls: Type[CheckType], name: str, config: configparser.SectionProxy
+        cls: type[CheckType], name: str, config: configparser.SectionProxy
     ) -> CheckType:
         """Create a new check instance from the provided configuration.
 
@@ -59,7 +60,7 @@ class Check(abc.ABC):
 
         """
 
-    def __init__(self, name: Optional[str] = None) -> None:
+    def __init__(self, name: str | None = None) -> None:
         if name:
             self.name = name
         else:
@@ -76,9 +77,7 @@ class Check(abc.ABC):
         }
 
     def __str__(self) -> str:
-        return "{name}[class={clazz}]".format(
-            name=self.name, clazz=self.__class__.__name__
-        )
+        return f"{self.name}[class={self.__class__.__name__}]"
 
 
 class Activity(Check):
@@ -88,7 +87,7 @@ class Activity(Check):
     """
 
     @abc.abstractmethod
-    def check(self) -> Optional[str]:
+    def check(self) -> str | None:
         """Determine if system activity exists that prevents suspending.
 
         Returns:
@@ -102,16 +101,14 @@ class Activity(Check):
         """
 
     def __str__(self) -> str:
-        return "{name}[class={clazz}]".format(
-            name=self.name, clazz=self.__class__.__name__
-        )
+        return f"{self.name}[class={self.__class__.__name__}]"
 
 
 class Wakeup(Check):
     """Represents a check for potential wake up points."""
 
     @abc.abstractmethod
-    def check(self, timestamp: datetime) -> Optional[datetime]:
+    def check(self, timestamp: datetime) -> datetime | None:
         """Indicate if a wakeup has to be scheduled for this check.
 
         Args:
